@@ -38,8 +38,6 @@ do
     fi
 done
 
-cp hack/podman-registry /bin
-
 # Bypass git safety/security checks when operating in a throwaway environment
 showrun git config --global --add safe.directory $GOSRC
 
@@ -367,11 +365,6 @@ case "$TEST_FLAVOR" in
         showrun pip install --upgrade pip
         showrun pip install --requirement $GOSRC/test/apiv2/python/requirements.txt
         ;&  # continue with next item
-    compose)
-        showrun make install.tools
-        showrun dnf remove -y gvisor-tap-vsock
-        showrun dnf install -y podman-docker*
-        ;&  # continue with next item
     int)
         showrun make .install.ginkgo
         ;&
