@@ -10,9 +10,11 @@ import (
 	"os"
 	"path"
 	"path/filepath"
+	"runtime"
 
 	"github.com/containers/podman/v5/pkg/machine/define"
 	"github.com/containers/podman/v5/pkg/systemd/parser"
+	"github.com/containers/storage/pkg/fileutils"
 	"github.com/sirupsen/logrus"
 )
 
@@ -64,6 +66,7 @@ type DynamicIgnition struct {
 	Cfg        Config
 	Rootful    bool
 	NetRecover bool
+	Rosetta    bool
 }
 
 func (ign *DynamicIgnition) Write() error {
@@ -238,6 +241,19 @@ func (ign *DynamicIgnition) GenerateIgnitionConfig() error {
 		ignSystemd.Units = append(ignSystemd.Units, qemuUnit)
 	}
 
+	// Only AppleHv with Apple Silicon can use Rosetta
+	if ign.VMType == define.AppleHvVirt && runtime.GOARCH == "arm64" {
+		rosettaUnit := Systemd{
+			Units: []Unit{
+				{
+					Enabled: BoolToPtr(true),
+					Name:    "rosetta-activation.service",
+				},
+			},
+		}
+		ignSystemd.Units = append(ignSystemd.Units, rosettaUnit.Units...)
+	}
+
 	// Only after all checks are done
 	// it's ready create the ingConfig
 	ign.Cfg = Config{
@@ -406,7 +422,7 @@ pids_limit=0
 
 	sslCertFileName, ok := os.LookupEnv(sslCertFile)
 	if ok {
-		if _, err := os.Stat(sslCertFileName); err == nil {
+		if err := fileutils.Exists(sslCertFileName); err == nil {
 			certFiles = getCerts(sslCertFileName, false)
 			files = append(files, certFiles...)
 		} else {
@@ -416,7 +432,7 @@ pids_limit=0
 
 	sslCertDirName, ok := os.LookupEnv(sslCertDir)
 	if ok {
-		if _, err := os.Stat(sslCertDirName); err == nil {
+		if err := fileutils.Exists(sslCertDirName); err == nil {
 			certFiles = getCerts(sslCertDirName, true)
 			files = append(files, certFiles...)
 		} else {
